@@ -156,6 +156,7 @@ class ImageDirective(Directive):
     def is_remote(self, uri):
         uri = uri.strip()
         env = self.state.document.settings.env
+        app_directory = os.path.dirname(os.path.abspath(self.state.document.settings._source))
 
         if uri.startswith('/'):
             return False
@@ -163,6 +164,8 @@ class ImageDirective(Directive):
             return False
         if os.path.isfile(os.path.join(env.srcdir, uri)):
             return False
+        if os.path.isfile(os.path.join(app_directory, uri)):
+            return False
         if '://' in uri:
             return True
         raise ValueError('Image URI `{}` have to be local relative or '
